@@ -1,3 +1,4 @@
+# pylint: disable=R0913,W0703
 #  Drakkar-Software OctoBot-Commons
 #  Copyright (c) Drakkar-Software, All rights reserved.
 #
@@ -20,6 +21,7 @@ import shutil
 import pathlib
 import uuid
 import time
+import requests
 import octobot_commons.constants as constants
 import octobot_commons.logging as bot_logging
 
@@ -58,6 +60,7 @@ def install_profile(
     bot_install_path: str,
     replace_if_exists: bool,
     is_imported: bool,
+    origin_url: str = None,
 ) -> Profile:
     """
     Installs the given profile export archive into the user's profile directory
@@ -66,6 +69,7 @@ def install_profile(
     :param bot_install_path: path to the octobot installation
     :param replace_if_exists: when True erase the profile with the same name if it exists
     :param is_imported: when True erase the profile is set as imported
+    :param origin_url: url the profile is coming from (if relevant)
     :return: The created profile
     """
     logger = bot_logging.get_logger("ProfileSharing")
@@ -79,6 +83,7 @@ def install_profile(
     _import_profile_files(import_path, target_import_path)
     profile = Profile(target_import_path).read_config()
     profile.imported = is_imported
+    profile.origin_url = origin_url
     _ensure_unique_profile_id(profile)
     logger.info(f"{action}ed {profile.name} ({profile_name}) profile.")
     return profile
@@ -88,16 +93,68 @@ def import_profile(
     import_path: str,
     name: str = None,
     bot_install_path: str = ".",
+    origin_url: str = None,
 ) -> Profile:
     """
     Imports the given profile export archive into the user's profile directory with the "imported_" prefix
     :param import_path: path to the profile zipped archive
     :param name: name of the profile folder
     :param bot_install_path: path to the octobot installation
+    :param origin_url: url the profile is coming from
     :return: The created profile
     """
-    profile_name = _get_profile_name(name, import_path)
-    return install_profile(import_path, profile_name, bot_install_path, False, True)
+    temp_profile_name = _get_profile_name(name, import_path)
+    profile = install_profile(
+        import_path,
+        temp_profile_name,
+        bot_install_path,
+        False,
+        True,
+        origin_url=origin_url,
+    )
+    if profile.name != temp_profile_name:
+        profile.rename_folder(_get_unique_profile_folder_from_name(profile), False)
+    return profile
+
+
+def download_profile(url, target_file, timeout=60):
+    """
+    Downloads a profile from the given url
+    :param url: profile url
+    :param target_file: path to save the file
+    :param timeout: time given to the request before timeout
+    :return: saved file path
+    """
+    # unauthenticated download
+    with requests.get(url, stream=True, timeout=timeout) as req:
+        req.raise_for_status()
+        with open(target_file, "wb") as write_file:
+            for chunk in req.iter_content(chunk_size=8192):
+                write_file.write(chunk)
+    return target_file
+
+
+def download_and_install_profile(download_url):
+    """
+    :param download_url: profile url
+    :return: the installed profile, None if an error occurred
+    """
+    logger = bot_logging.get_logger("ProfileSharing")
+    name = download_url.split("/")[-1]
+    file_path = None
+    try:
+        file_path = download_profile(download_url, name)
+        profile = import_profile(file_path, name=name, origin_url=download_url)
+        logger.info(
+            f"Downloaded and installed {profile.name} from {profile.origin_url}"
+        )
+        return profile
+    except Exception as err:
+        logger.exception(err, True, f"Error when installing profile: {err}")
+        return None
+    finally:
+        if file_path is not None and os.path.isfile(file_path):
+            os.remove(file_path)
 
 
 def _get_profile_name(name, import_path):
@@ -165,6 +222,13 @@ def _import_profile_files(profile_path: str, target_profile_path: str) -> None:
         shutil.copytree(profile_path, target_profile_path)
 
 
+def _get_unique_profile_folder_from_name(profile) -> str:
+    folder = _get_unique_profile_folder(
+        os.path.join(os.path.split(profile.path)[0], profile.name)
+    )
+    return os.path.split(folder)[1]
+
+
 def _get_unique_profile_folder(target_import_path: str) -> str:
     """
     Creates an unique profile folder name
